@@ -179,7 +179,7 @@ def _timezone_dst_offsets(api_inputs: ApiInputs, date_from: datetime.date, date_
         timezone_offsets = pandas.DataFrame.from_dict(timezone_intervals['dstTransitions'])
         timezone_offsets = timezone_offsets.explode('dstIntervals')
         timezone_offsets = timezone_offsets.reset_index(drop=True).join(timezone_offsets.reset_index(drop=True)
-                                                                        .dstIntervals.apply(pandas.Series)).drop(columns=['dstIntervals'])
+                                                                        .dstIntervals.apply(pandas.Series)).drop(columns=['dstIntervals', 'timezoneName'])
         return site_timezones.merge(timezone_offsets, on='timezoneId')
     except Exception as ex:
         logger.error("API Call was not successful.", ex)
