@@ -922,12 +922,17 @@ def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time
         data_frame['Meta'] = ''
 
     if api_inputs.data_feed_file_status_id is not None and \
-            api_inputs.data_feed_file_status_id != '00000000-0000-0000-0000-000000000000':
+            api_inputs.data_feed_file_status_id != '00000000-0000-0000-0000-000000000000' and \
+            api_inputs.data_feed_file_status_id != '':
         data_frame['DataFeedFileStatusId'] = api_inputs.data_feed_file_status_id
-    elif data_feed_file_status_id is not None:
+        data_feed_file_status_id = api_inputs.data_feed_file_status_id
+    elif data_feed_file_status_id is not None and \
+            data_feed_file_status_id != '00000000-0000-0000-0000-000000000000' and \
+            data_feed_file_status_id != '':
         data_frame['DataFeedFileStatusId'] = data_feed_file_status_id
     else:
-        data_frame['DataFeedFileStatusId'] = '00000000-0000-0000-0000-000000000000'
+        data_feed_file_status_id = uuid.uuid4()
+        data_frame['DataFeedFileStatusId'] = data_feed_file_status_id
 
     if not pandas.api.types.is_datetime64_ns_dtype(data_frame['Timestamp']):
         logger.exception("Timestamp series value is not of type: datetime64[ns] dtype.")
